@@ -4,8 +4,8 @@ set -e
 mkdir -p build && cd build
 rm * -rf
 meson .. \
-    -Denable-gtk-doc=true \
-    -Denable-stemmer=true $@
+    -Dgtk-doc=true \
+    -Dstemmer=true $@
 ninja -v
 ninja test -v
 DESTDIR=/tmp/install-ninja ninja install
