@@ -294,7 +294,7 @@ as_app_builder_parse_file_qt (AsAppBuilderContext *ctx,
 			      const gchar *filename,
 			      GError **error)
 {
-	guint32 len;
+	gsize len;
 	guint32 m = 0;
 	g_autofree guint8 *data = NULL;
 	const guint8 qm_magic[] = {
@@ -303,7 +303,7 @@ as_app_builder_parse_file_qt (AsAppBuilderContext *ctx,
 	};
 
 	/* load file */
-	if (!g_file_get_contents (filename, (gchar **) &data, (gsize *) &len, error))
+	if (!g_file_get_contents (filename, (gchar **) &data, &len, error))
 		return FALSE;
 
 	/* check header */
@@ -321,6 +321,13 @@ as_app_builder_parse_file_qt (AsAppBuilderContext *ctx,
 	while (m < len) {
 		AsAppBuilderQmSection section = _read_uint8(data, &m);
 		guint32 section_len = _read_uint32 (data, &m);
+		if (section_len > len - m) {
+			g_set_error_literal (error,
+					     AS_APP_ERROR,
+					     AS_APP_ERROR_FAILED,
+					     "file is invalid, section too large");
+			return FALSE;
+		}
 		if (section == AS_APP_TRANSLATION_QM_SECTION_MESSAGES) {
 			as_app_builder_parse_data_qt (ctx,
 						      locale,
@@ -505,7 +512,6 @@ as_app_builder_search_translations_pak (AsAppBuilderContext *ctx,
 	for (i = 0; i < ctx->translations->len; i++) {
 		const gchar *tmp;
 		g_autoptr(GDir) dir = NULL;
-		g_autofree gchar *path = NULL;
 		AsTranslation *t = g_ptr_array_index (ctx->translations, i);
 		const gchar *libdirs[] = { "lib64", "lib", NULL };
 
@@ -513,6 +519,7 @@ as_app_builder_search_translations_pak (AsAppBuilderContext *ctx,
 		if (as_translation_get_id (t) == NULL)
 			continue;
 		for (guint j = 0; libdirs[j] != NULL; j++) {
+			g_autofree gchar *path = NULL;
 			path = g_build_filename (prefix,
 						 libdirs[j],
 						 as_translation_get_id (t),
@@ -576,12 +583,12 @@ as_app_builder_search_translations_xpi (AsAppBuilderContext *ctx,
 					GError **error)
 {
 	const gchar *tmp;
-	g_autofree gchar *path = NULL;
 	g_autoptr(GDir) dir = NULL;
 	const gchar *libdirs[] = { "lib64", "lib", NULL };
 
 	/* list files */
 	for (guint j = 0; libdirs[j] != NULL; j++) {
+		g_autofree gchar *path = NULL;
 		path = g_build_filename (prefix,
 					 libdirs[j],
 					 "firefox",
