@@ -57,6 +57,7 @@ G_BEGIN_DECLS
  * @AS_APP_PROBLEM_DUPLICATE_RELEASE:		More than one release with the same version
  * @AS_APP_PROBLEM_DUPLICATE_SCREENSHOT:	More than one screenshot with the same URL
  * @AS_APP_PROBLEM_DUPLICATE_CONTENT_RATING:	More than one content rating with the same kind
+ * @AS_APP_PROBLEM_DUPLICATE_AGREEMENT:		More than one agreement with the same kind
  *
  * The application problems detected when loading.
  **/
@@ -82,6 +83,7 @@ typedef enum {
 	AS_APP_PROBLEM_DUPLICATE_RELEASE	= 1 << 17,
 	AS_APP_PROBLEM_DUPLICATE_SCREENSHOT	= 1 << 18,
 	AS_APP_PROBLEM_DUPLICATE_CONTENT_RATING	= 1 << 19,
+	AS_APP_PROBLEM_DUPLICATE_AGREEMENT	= 1 << 20,
 	/*< private >*/
 	AS_APP_PROBLEM_LAST
 } AsAppProblems;
@@ -123,6 +125,10 @@ void		 as_app_set_stemmer		(AsApp		*app,
 						 AsStemmer	*stemmer);
 void		 as_app_set_search_blacklist	(AsApp		*app,
 						 GHashTable	*search_blacklist);
+void		 as_app_set_icon_path_rstr	(AsApp		*app,
+						 AsRefString	*rstr);
+void		 as_app_set_origin_rstr		(AsApp		*app,
+						 AsRefString	*rstr);
 
 G_END_DECLS
 
