@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2014-2018 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -30,7 +30,9 @@
 
 #include "as-bundle.h"
 #include "as-enums.h"
+#include "as-format.h"
 #include "as-icon.h"
+#include "as-launchable.h"
 #include "as-provide.h"
 #include "as-release.h"
 #include "as-screenshot.h"
@@ -38,6 +40,7 @@
 #include "as-review.h"
 #include "as-suggest.h"
 #include "as-content-rating.h"
+#include "as-agreement.h"
 #include "as-translation.h"
 
 G_BEGIN_DECLS
@@ -106,6 +109,7 @@ typedef enum {
  * @AS_APP_SUBSUME_FLAG_SCREENSHOTS:	Copy the screenshots
  * @AS_APP_SUBSUME_FLAG_REVIEWS:	Copy the reviews
  * @AS_APP_SUBSUME_FLAG_CONTENT_RATINGS: Copy the content ratings
+ * @AS_APP_SUBSUME_FLAG_AGREEMENTS:	Copy the agreements
  * @AS_APP_SUBSUME_FLAG_PROVIDES:	Copy the provides
  * @AS_APP_SUBSUME_FLAG_ICONS:		Copy the icons
  * @AS_APP_SUBSUME_FLAG_MIMETYPES:	Copy the mimetypes
@@ -118,13 +122,14 @@ typedef enum {
  * @AS_APP_SUBSUME_FLAG_METADATA:	Copy the metadata
  * @AS_APP_SUBSUME_FLAG_URL:		Copy the urls
  * @AS_APP_SUBSUME_FLAG_KEYWORDS:	Copy the keywords
- * @AS_APP_SUBSUME_FLAG_SOURCE_FILE:	Copy the source file
+ * @AS_APP_SUBSUME_FLAG_FORMATS:	Copy the source file
  * @AS_APP_SUBSUME_FLAG_BRANCH:		Copy the branch
  * @AS_APP_SUBSUME_FLAG_ORIGIN:		Copy the origin
  * @AS_APP_SUBSUME_FLAG_METADATA_LICENSE: Copy the metadata license
  * @AS_APP_SUBSUME_FLAG_PROJECT_LICENSE: Copy the project license
  * @AS_APP_SUBSUME_FLAG_PROJECT_GROUP:	Copy the project group
  * @AS_APP_SUBSUME_FLAG_SOURCE_KIND:	Copy the source kind
+ * @AS_APP_SUBSUME_FLAG_LAUNCHABLES:	Copy the launchables
  *
  * The flags to use when subsuming applications.
  **/
@@ -158,7 +163,7 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_METADATA		= 1ull << 25,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_URL			= 1ull << 26,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_KEYWORDS		= 1ull << 27,	/* Since: 0.6.1 */
-	AS_APP_SUBSUME_FLAG_SOURCE_FILE		= 1ull << 28,	/* Since: 0.6.1 */
+	AS_APP_SUBSUME_FLAG_FORMATS		= 1ull << 28,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_BRANCH		= 1ull << 29,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_ORIGIN		= 1ull << 30,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_METADATA_LICENSE	= 1ull << 31,	/* Since: 0.6.1 */
@@ -166,15 +171,21 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_PROJECT_GROUP	= 1ull << 33,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1ull << 34,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SUGGESTS		= 1ull << 35,	/* Since: 0.6.3 */
+	AS_APP_SUBSUME_FLAG_LAUNCHABLES		= 1ull << 36,	/* Since: 0.6.13 */
+	AS_APP_SUBSUME_FLAG_AGREEMENTS		= 1ull << 37,	/* Since: 0.7.8 */
 	/*< private >*/
 	AS_APP_SUBSUME_FLAG_LAST,
 } AsAppSubsumeFlags;
 
+/* deprecated */
+#define AS_APP_SUBSUME_FLAG_SOURCE_FILE		AS_APP_SUBSUME_FLAG_FORMATS
+
 /* safe to do from a merge <component> */
 #define AS_APP_SUBSUME_FLAG_MERGE	(AS_APP_SUBSUME_FLAG_CATEGORIES | \
 					 AS_APP_SUBSUME_FLAG_COMMENT | \
 					 AS_APP_SUBSUME_FLAG_COMPULSORY | \
 					 AS_APP_SUBSUME_FLAG_CONTENT_RATINGS | \
+					 AS_APP_SUBSUME_FLAG_AGREEMENTS | \
 					 AS_APP_SUBSUME_FLAG_DESCRIPTION | \
 					 AS_APP_SUBSUME_FLAG_DEVELOPER_NAME | \
 					 AS_APP_SUBSUME_FLAG_EXTENDS | \
@@ -193,6 +204,8 @@ typedef enum {
 					 AS_APP_SUBSUME_FLAG_SCREENSHOTS | \
 					 AS_APP_SUBSUME_FLAG_SUGGESTS | \
 					 AS_APP_SUBSUME_FLAG_TRANSLATIONS | \
+					 AS_APP_SUBSUME_FLAG_SOURCE_KIND | \
+					 AS_APP_SUBSUME_FLAG_LAUNCHABLES | \
 					 AS_APP_SUBSUME_FLAG_URL)
 
 /* deprecated name */
@@ -206,8 +219,7 @@ typedef enum {
 					 AS_APP_SUBSUME_FLAG_METADATA | \
 					 AS_APP_SUBSUME_FLAG_ORIGIN | \
 					 AS_APP_SUBSUME_FLAG_PROJECT_LICENSE | \
-					 AS_APP_SUBSUME_FLAG_SOURCE_FILE | \
-					 AS_APP_SUBSUME_FLAG_SOURCE_KIND | \
+					 AS_APP_SUBSUME_FLAG_FORMATS | \
 					 AS_APP_SUBSUME_FLAG_STATE | \
 					 AS_APP_SUBSUME_FLAG_VETOS)
 
@@ -271,17 +283,16 @@ typedef enum {
  * @AS_APP_SOURCE_KIND_INF:			Sourced from a inf file
  *
  * The source kind.
+ *
+ * This has been deprecated since 0.6.9 in favour of using AsFormatKind.
  **/
-typedef enum {
-	AS_APP_SOURCE_KIND_UNKNOWN,		/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_APPSTREAM,		/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_DESKTOP,		/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_APPDATA,		/* Since: 0.1.4 */
-	AS_APP_SOURCE_KIND_METAINFO,		/* Since: 0.1.7 */
-	AS_APP_SOURCE_KIND_INF,			/* Since: 0.3.5 (deprecated 0.6.2) */
-	/*< private >*/
-	AS_APP_SOURCE_KIND_LAST
-} AsAppSourceKind;
+typedef AsFormatKind AsAppSourceKind;
+#define	AS_APP_SOURCE_KIND_UNKNOWN	AS_FORMAT_KIND_UNKNOWN		/* Since: 0.1.4 */
+#define	AS_APP_SOURCE_KIND_APPSTREAM	AS_FORMAT_KIND_APPSTREAM	/* Since: 0.1.4 */
+#define	AS_APP_SOURCE_KIND_DESKTOP	AS_FORMAT_KIND_DESKTOP		/* Since: 0.1.4 */
+#define	AS_APP_SOURCE_KIND_APPDATA	AS_FORMAT_KIND_APPDATA		/* Since: 0.1.4 */
+#define	AS_APP_SOURCE_KIND_METAINFO	AS_FORMAT_KIND_METAINFO		/* Since: 0.1.7 */
+#define	AS_APP_SOURCE_KIND_INF		AS_FORMAT_KIND_UNKNOWN		/* Since: 0.3.5 */
 
 /**
  * AsAppKind:
@@ -300,6 +311,7 @@ typedef enum {
  * @AS_APP_KIND_OS_UPGRADE:		Operating system upgrade
  * @AS_APP_KIND_SHELL_EXTENSION:	GNOME Shell extension
  * @AS_APP_KIND_LOCALIZATION:		Localization data
+ * @AS_APP_KIND_CONSOLE:		Console program
  * @AS_APP_KIND_DRIVER:			Driver for hardware support
  *
  * The component type.
@@ -340,6 +352,7 @@ typedef enum {
  * @AS_APP_QUIRK_NEEDS_USER_ACTION:	The component requires some kind of user action
  * @AS_APP_QUIRK_IS_PROXY:		Is a proxy app that operates on other applications
  * @AS_APP_QUIRK_REMOVABLE_HARDWARE:	The device is unusable whilst the action is performed
+ * @AS_APP_QUIRK_DEVELOPER_VERIFIED:	The app developer has been verified
  *
  * The component attributes.
  **/
@@ -356,6 +369,7 @@ typedef enum {
 	AS_APP_QUIRK_NEEDS_USER_ACTION	= 1 << 8,	/* Since: 0.6.2 */
 	AS_APP_QUIRK_IS_PROXY 		= 1 << 9,	/* Since: 0.6.6 */
 	AS_APP_QUIRK_REMOVABLE_HARDWARE	= 1 << 10,	/* Since: 0.6.6 */
+	AS_APP_QUIRK_DEVELOPER_VERIFIED	= 1 << 11,	/* Since: 0.7.11 */
 	/*< private >*/
 	AS_APP_QUIRK_LAST
 } AsAppQuirk;
@@ -438,6 +452,7 @@ typedef enum {
  * @AS_APP_SEARCH_MATCH_NAME:			Use the app name
  * @AS_APP_SEARCH_MATCH_KEYWORD:		Use the app keyword
  * @AS_APP_SEARCH_MATCH_ID:			Use the app application ID
+ * @AS_APP_SEARCH_MATCH_ORIGIN:			Use the app origin
  *
  * The token match kind, which we want to be exactly 16 bits for storage
  * reasons.
@@ -451,6 +466,7 @@ typedef enum __attribute__((__packed__)) {
 	AS_APP_SEARCH_MATCH_NAME	= 1 << 4,	/* Since: 0.6.5 */
 	AS_APP_SEARCH_MATCH_KEYWORD	= 1 << 5,	/* Since: 0.6.5 */
 	AS_APP_SEARCH_MATCH_ID		= 1 << 6,	/* Since: 0.6.5 */
+	AS_APP_SEARCH_MATCH_ORIGIN	= 1 << 7,	/* Since: 0.6.13 */
 	/*< private >*/
 	AS_APP_SEARCH_MATCH_LAST	= 0xffff
 } AsAppSearchMatch;
@@ -459,9 +475,6 @@ typedef enum __attribute__((__packed__)) {
 
 AsApp		*as_app_new			(void);
 GQuark		 as_app_error_quark		(void);
-AsAppSourceKind	 as_app_guess_source_kind	(const gchar	*filename);
-AsAppSourceKind	 as_app_source_kind_from_string	(const gchar	*source_kind);
-const gchar	*as_app_source_kind_to_string	(AsAppSourceKind source_kind);
 const gchar	*as_app_state_to_string		(AsAppState	 state);
 const gchar	*as_app_kind_to_string		(AsAppKind	 kind);
 AsAppKind	 as_app_kind_from_string	(const gchar	*kind);
@@ -472,11 +485,11 @@ const gchar	*as_app_merge_kind_to_string	(AsAppMergeKind	 merge_kind);
 
 /* getters */
 AsAppKind	 as_app_get_kind		(AsApp		*app);
-AsAppSourceKind	 as_app_get_source_kind		(AsApp		*app);
 AsAppScope	 as_app_get_scope		(AsApp		*app);
 AsAppMergeKind	 as_app_get_merge_kind		(AsApp		*app);
 AsAppState	 as_app_get_state		(AsApp		*app);
-AsAppTrustFlags	 as_app_get_trust_flags		(AsApp		*app);
+guint32		 as_app_get_trust_flags		(AsApp		*app);
+guint16		 as_app_get_search_match	(AsApp		*app);
 GList		*as_app_get_languages		(AsApp		*app);
 GPtrArray	*as_app_get_addons		(AsApp		*app);
 GPtrArray	*as_app_get_categories		(AsApp		*app);
@@ -486,11 +499,13 @@ GPtrArray	*as_app_get_keywords		(AsApp		*app,
 						 const gchar	*locale);
 GPtrArray	*as_app_get_kudos		(AsApp		*app);
 GPtrArray	*as_app_get_permissions		(AsApp		*app);
+GPtrArray	*as_app_get_formats		(AsApp		*app);
 GPtrArray	*as_app_get_mimetypes		(AsApp		*app);
 GPtrArray	*as_app_get_pkgnames		(AsApp		*app);
 GPtrArray	*as_app_get_architectures	(AsApp		*app);
 GPtrArray	*as_app_get_releases		(AsApp		*app);
 GPtrArray	*as_app_get_provides		(AsApp		*app);
+GPtrArray	*as_app_get_launchables		(AsApp		*app);
 GPtrArray	*as_app_get_screenshots		(AsApp		*app);
 GPtrArray	*as_app_get_reviews		(AsApp		*app);
 GPtrArray	*as_app_get_content_ratings	(AsApp		*app);
@@ -518,7 +533,6 @@ const gchar	*as_app_get_project_group	(AsApp		*app);
 const gchar	*as_app_get_project_license	(AsApp		*app);
 const gchar	*as_app_get_metadata_license	(AsApp		*app);
 const gchar	*as_app_get_update_contact	(AsApp		*app);
-const gchar	*as_app_get_source_file		(AsApp		*app);
 const gchar	*as_app_get_branch		(AsApp		*app);
 const gchar	*as_app_get_name		(AsApp		*app,
 						 const gchar	*locale);
@@ -543,18 +557,24 @@ gboolean	 as_app_has_kudo_kind		(AsApp		*app,
 						 AsKudoKind	 kudo);
 gboolean	 as_app_has_permission		(AsApp		*app,
 						 const gchar	*permission);
+AsFormat	*as_app_get_format_default	(AsApp		*app);
+AsFormat	*as_app_get_format_by_kind	(AsApp		*app,
+						 AsFormatKind	 kind);
+AsFormat	*as_app_get_format_by_filename	(AsApp		*app,
+						 const gchar	*filename);
 gboolean	 as_app_has_compulsory_for_desktop (AsApp	*app,
 						 const gchar	*desktop);
 gboolean	 as_app_has_quirk		(AsApp		*app,
 						 AsAppQuirk	 quirk);
+AsLaunchable	*as_app_get_launchable_default	(AsApp		*app);
+AsLaunchable	*as_app_get_launchable_by_kind	(AsApp		*app,
+						 AsLaunchableKind kind);
 
 /* setters */
 void		 as_app_set_id			(AsApp		*app,
 						 const gchar	*id);
 void		 as_app_set_kind		(AsApp		*app,
 						 AsAppKind	 kind);
-void		 as_app_set_source_kind		(AsApp		*app,
-						 AsAppSourceKind source_kind);
 void		 as_app_set_scope		(AsApp		*app,
 						 AsAppScope	 scope);
 void		 as_app_set_merge_kind		(AsApp		*app,
@@ -562,7 +582,9 @@ void		 as_app_set_merge_kind		(AsApp		*app,
 void		 as_app_set_state		(AsApp		*app,
 						 AsAppState	 state);
 void		 as_app_set_trust_flags		(AsApp		*app,
-						 AsAppTrustFlags trust_flags);
+						 guint32	 trust_flags);
+void		 as_app_set_search_match	(AsApp		*app,
+						 guint16	 search_match);
 void		 as_app_set_origin		(AsApp		*app,
 						 const gchar	*origin);
 void		 as_app_set_project_group	(AsApp		*app,
@@ -589,23 +611,29 @@ void		 as_app_set_developer_name	(AsApp		*app,
 void		 as_app_set_description		(AsApp		*app,
 						 const gchar	*locale,
 						 const gchar	*description);
-void		 as_app_set_source_file		(AsApp		*app,
-						 const gchar	*source_file);
 void		 as_app_set_branch		(AsApp		*app,
 						 const gchar	*branch);
 void		 as_app_set_priority		(AsApp		*app,
 						 gint		 priority);
 void		 as_app_add_category		(AsApp		*app,
 						 const gchar	*category);
+void		 as_app_remove_category		(AsApp		*app,
+						 const gchar	*category);
 void		 as_app_add_keyword		(AsApp		*app,
 						 const gchar	*locale,
 						 const gchar	*keyword);
 void		 as_app_add_kudo		(AsApp		*app,
 						 const gchar	*kudo);
+void		 as_app_remove_kudo		(AsApp		*app,
+						 const gchar	*kudo);
 void		 as_app_add_kudo_kind		(AsApp		*app,
 						 AsKudoKind	 kudo_kind);
 void		 as_app_add_permission		(AsApp		*app,
 						 const gchar	*permission);
+void		 as_app_add_format		(AsApp		*app,
+						 AsFormat	*format);
+void		 as_app_remove_format		(AsApp		*app,
+						 AsFormat	*format);
 void		 as_app_add_mimetype		(AsApp		*app,
 						 const gchar	*mimetype);
 void		 as_app_add_pkgname		(AsApp		*app,
@@ -616,12 +644,16 @@ void		 as_app_add_release		(AsApp		*app,
 						 AsRelease	*release);
 void		 as_app_add_provide		(AsApp		*app,
 						 AsProvide	*provide);
+void		 as_app_add_launchable		(AsApp		*app,
+						 AsLaunchable	*launchable);
 void		 as_app_add_screenshot		(AsApp		*app,
 						 AsScreenshot	*screenshot);
 void		 as_app_add_review		(AsApp		*app,
 						 AsReview	*review);
 void		 as_app_add_content_rating	(AsApp		*app,
 						 AsContentRating *content_rating);
+void		 as_app_add_agreement		(AsApp		*app,
+						 AsAgreement	*agreement);
 void		 as_app_add_icon		(AsApp		*app,
 						 AsIcon		*icon);
 void		 as_app_add_bundle		(AsApp		*app,
@@ -654,13 +686,13 @@ void		 as_app_add_quirk		(AsApp		*app,
 
 /* object methods */
 GPtrArray	*as_app_validate		(AsApp		*app,
-						 AsAppValidateFlags flags,
+						 guint32	 flags,
 						 GError		**error);
 void		 as_app_subsume			(AsApp		*app,
 						 AsApp		*donor);
 void		 as_app_subsume_full		(AsApp		*app,
 						 AsApp		*donor,
-						 AsAppSubsumeFlags flags);
+						 guint64	 flags);
 void		 as_app_add_veto		(AsApp		*app,
 						 const gchar	*fmt,
 						 ...)
@@ -673,14 +705,24 @@ guint		 as_app_search_matches		(AsApp		*app,
 						 const gchar	*search);
 gboolean	 as_app_parse_file		(AsApp		*app,
 						 const gchar	*filename,
-						 AsAppParseFlags flags,
+						 guint32	 flags,
+						 GError		**error);
+gboolean	 as_app_parse_data		(AsApp		*app,
+						 GBytes		*data,
+						 guint32	 flags,
 						 GError		**error);
 gboolean	 as_app_to_file			(AsApp		*app,
 						 GFile		*file,
 						 GCancellable	*cancellable,
 						 GError		**error);
+GString		*as_app_to_xml			(AsApp		*app,
+						 GError		**error);
 AsContentRating	*as_app_get_content_rating	(AsApp		*app,
 						 const gchar 	*kind);
+AsAgreement	*as_app_get_agreement_by_kind	(AsApp		*app,
+						 AsAgreementKind kind);
+AsAgreement	*as_app_get_agreement_default	(AsApp		*app);
+AsScreenshot	*as_app_get_screenshot_default	(AsApp		*app);
 AsIcon		*as_app_get_icon_default	(AsApp		*app);
 AsIcon		*as_app_get_icon_for_size	(AsApp		*app,
 						 guint		 width,
@@ -689,6 +731,8 @@ AsBundle	*as_app_get_bundle_default	(AsApp		*app);
 AsRelease	*as_app_get_release		(AsApp		*app,
 						 const gchar	*version);
 AsRelease	*as_app_get_release_default	(AsApp		*app);
+AsRelease	*as_app_get_release_by_version	(AsApp		*app,
+						 const gchar	*version);
 AsRequire	*as_app_get_require_by_value	(AsApp		*app,
 						 AsRequireKind	 kind,
 						 const gchar	*value);
@@ -705,6 +749,27 @@ G_DEPRECATED_FOR(as_app_get_kind);
 void		 as_app_set_id_kind		(AsApp		*app,
 						 AsIdKind	 id_kind)
 G_DEPRECATED_FOR(as_app_set_kind);
+
+void		 as_app_set_source_file		(AsApp		*app,
+						 const gchar	*source_file)
+G_DEPRECATED_FOR(as_app_add_format);
+const gchar	*as_app_get_source_file		(AsApp		*app)
+G_DEPRECATED_FOR(as_app_get_formats);
+
+AsFormatKind	 as_app_get_source_kind		(AsApp		*app)
+G_DEPRECATED_FOR(as_format_get_kind);
+void		 as_app_set_source_kind		(AsApp		*app,
+						 AsFormatKind source_kind)
+G_DEPRECATED_FOR(as_format_set_kind);
+
+AsFormatKind	 as_app_source_kind_from_string	(const gchar	*source_kind)
+G_DEPRECATED_FOR(as_format_kind_from_string);
+const gchar	*as_app_source_kind_to_string	(AsFormatKind source_kind)
+G_DEPRECATED_FOR(as_format_kind_to_string);
+
+AsFormatKind	 as_app_guess_source_kind	(const gchar	*filename)
+G_DEPRECATED_FOR(as_format_guess_kind);
+
 G_GNUC_END_IGNORE_DEPRECATIONS
 
 G_END_DECLS
