@@ -50,8 +50,9 @@ struct _AsChecksumClass
 /**
  * AsChecksumTarget:
  * @AS_CHECKSUM_TARGET_UNKNOWN:			Unknown state
- * @AS_CHECKSUM_TARGET_CONTAINER:		Container file, e.g. ".cab"
- * @AS_CHECKSUM_TARGET_CONTENT:			Extracted file, e.g. ".bin"
+ * @AS_CHECKSUM_TARGET_CONTAINER:		Container file, e.g. `.cab`
+ * @AS_CHECKSUM_TARGET_CONTENT:			Extracted file, e.g. `.bin`
+ * @AS_CHECKSUM_TARGET_SIGNATURE:		Signature, e.g. `.asc` or `.cat`
  *
  * The checksum target type.
  **/
@@ -59,6 +60,7 @@ typedef enum {
 	AS_CHECKSUM_TARGET_UNKNOWN,		/* Since: 0.4.2 */
 	AS_CHECKSUM_TARGET_CONTAINER,		/* Since: 0.4.2 */
 	AS_CHECKSUM_TARGET_CONTENT,		/* Since: 0.4.2 */
+	AS_CHECKSUM_TARGET_SIGNATURE,		/* Since: 0.7.9 */
 	/*< private >*/
 	AS_CHECKSUM_TARGET_LAST
 } AsChecksumTarget;
