@@ -61,6 +61,8 @@ void		 as_node_context_set_media_base_url (AsNodeContext	*ctx,
 AsRefString	*as_node_reflow_text		(const gchar	*text,
 						 gssize		 text_len);
 AsRefString	*as_node_fix_locale		(const gchar	*locale);
+AsRefString	*as_node_fix_locale_full	(const GNode	*node,
+						 const gchar	*locale);
 
 AsRefString	*as_node_get_data_as_refstr	(const AsNode	*node);
 AsRefString	*as_node_get_attribute_as_refstr (const AsNode	*node,
