@@ -45,6 +45,7 @@
 typedef struct {
 	GHashTable		*intern_attr;	/* key=value of AsRefString */
 	GHashTable		*intern_name;	/* key=value of AsRefString */
+	GHashTable		*intern_lang;	/* key=value of AsRefString */
 } AsNodeRoot;
 
 typedef struct
@@ -99,6 +100,10 @@ as_node_new (void)
 							 g_str_equal,
 							 (GDestroyNotify) as_ref_string_unref,
 							 NULL);
+	data->root->intern_lang = g_hash_table_new_full (g_str_hash,
+							 g_str_equal,
+							 (GDestroyNotify) as_ref_string_unref,
+							 NULL);
 	return g_node_new (data);
 }
 
@@ -108,13 +113,14 @@ as_node_attr_free (AsNodeAttr *attr)
 	g_slice_free (AsNodeAttr, attr);
 }
 
+/* transfer: none */
 static AsRefString *
 as_node_intern (GHashTable *hash, const gchar *key)
 {
 	AsRefString *rstr = g_hash_table_lookup (hash, key);
 	if (rstr == NULL) {
 		rstr = as_ref_string_new (key);
-		g_hash_table_insert (hash, rstr, rstr);
+		g_hash_table_add (hash, rstr);
 	}
 	return rstr;
 }
@@ -170,6 +176,7 @@ as_node_destroy_node_cb (AsNode *node, gpointer user_data)
 	if (data->is_root_node) {
 		g_hash_table_unref (data->root->intern_attr);
 		g_hash_table_unref (data->root->intern_name);
+		g_hash_table_unref (data->root->intern_lang);
 		g_free (data->root);
 	} else {
 		if (!data->is_cdata_const && data->cdata != NULL)
@@ -287,7 +294,7 @@ as_node_cdata_to_escaped (AsNodeData *data)
 		as_utils_string_replace (str, "&", "&amp;");
 		as_utils_string_replace (str, "<", "&lt;");
 		as_utils_string_replace (str, ">", "&gt;");
-		data->cdata = as_ref_string_new_copy_with_length (str->str, str->len);
+		data->cdata = as_ref_string_new_with_length (str->str, str->len);
 	}
 	data->is_cdata_escaped = TRUE;
 }
@@ -336,6 +343,8 @@ as_node_get_attr_string (AsNodeData *data)
 		as_utils_string_replace (value_safe, "&", "&amp;");
 		as_utils_string_replace (value_safe, "<", "&lt;");
 		as_utils_string_replace (value_safe, ">", "&gt;");
+		as_utils_string_replace (value_safe, "\"", "&quot;");
+		as_utils_string_replace (value_safe, "'", "&apos;");
 		g_string_append_printf (str, " %s=\"%s\"",
 					attr->key, value_safe->str);
 	}
@@ -518,7 +527,7 @@ as_node_reflow_text (const gchar *text, gssize text_len)
 	    !g_str_has_suffix (text, " ")) {
 		gsize len;
 		len = text_len >= 0 ? (gsize) text_len : strlen (text);
-		return as_ref_string_new_copy_with_length (text, len);
+		return as_ref_string_new_with_length (text, len);
 	}
 
 	/* split the text into lines */
@@ -553,7 +562,7 @@ as_node_reflow_text (const gchar *text, gssize text_len)
 		/* this last section was paragraph */
 		newline_count = 1;
 	}
-	return as_ref_string_new_copy_with_length (tmp->str, tmp->len);
+	return as_ref_string_new_with_length (tmp->str, tmp->len);
 }
 
 typedef struct {
@@ -607,7 +616,6 @@ as_node_start_element_cb (GMarkupParseContext *context,
 	AsNodeData *data;
 	AsNodeData *data_parent;
 	AsNode *current;
-	AsRefString *tmp;
 	guint i;
 
 	/* check if we should ignore the locale */
@@ -648,10 +656,13 @@ as_node_start_element_cb (GMarkupParseContext *context,
 	current = g_node_append_data (helper->current, data);
 
 	/* transfer the ownership of the comment to the new child */
-	tmp = as_node_get_attribute_as_refstr (helper->current, "@comment-tmp");
-	if (tmp != NULL) {
-		as_node_add_attribute (current, "@comment", tmp);
-		as_node_remove_attribute (helper->current, "@comment-tmp");
+	if (helper->flags & AS_NODE_FROM_XML_FLAG_KEEP_COMMENTS) {
+		AsRefString *tmp;
+		tmp = as_node_get_attribute_as_refstr (helper->current, "@comment-tmp");
+		if (tmp != NULL) {
+			as_node_add_attribute (current, "@comment", tmp);
+			as_node_remove_attribute (helper->current, "@comment-tmp");
+		}
 	}
 
 	/* the child is now the node to be processed */
@@ -1499,7 +1510,7 @@ as_node_find_with_attribute (AsNode *root, const gchar *path,
 	return node;
 }
 
-static gchar *
+static AsRefString *
 as_node_insert_line_breaks (const gchar *text, guint break_len)
 {
 	guint i;
@@ -1516,7 +1527,7 @@ as_node_insert_line_breaks (const gchar *text, guint break_len)
 	for (i = break_len + 1; i < str->len; i += break_len + 1)
 		g_string_insert (str, (gssize) i, "\n");
 	g_string_append (str, "\n");
-	return as_ref_string_new_copy_with_length (str->str, str->len);;
+	return as_ref_string_new_with_length (str->str, str->len);
 }
 
 /**
@@ -1616,7 +1627,7 @@ as_node_insert_localized (AsNode *parent,
 	as_node_data_set_name (root, data, name, insert_flags);
 	if (insert_flags & AS_NODE_INSERT_FLAG_NO_MARKUP) {
 		g_autofree gchar *tmp = as_markup_convert_simple (value_c, NULL);
-		data->cdata = as_ref_string_new_copy (tmp);
+		data->cdata = as_ref_string_new (tmp);
 		data->is_cdata_escaped = FALSE;
 	} else {
 		data->cdata = as_ref_string_new (value_c);
@@ -1642,7 +1653,7 @@ as_node_insert_localized (AsNode *parent,
 		as_node_data_set_name (root, data, name, insert_flags);
 		if (insert_flags & AS_NODE_INSERT_FLAG_NO_MARKUP) {
 			g_autofree gchar *tmp = as_markup_convert_simple (value, NULL);
-			data->cdata = as_ref_string_new_copy (tmp);
+			data->cdata = as_ref_string_new (tmp);
 			data->is_cdata_escaped = FALSE;
 		} else {
 			data->cdata = as_ref_string_new (value);
@@ -1784,9 +1795,7 @@ as_node_string_free (GString *string)
 }
 
 static void
-as_node_denorm_add_to_langs (GHashTable *hash,
-			     const gchar *data,
-			     gboolean is_start)
+as_node_denorm_add_to_langs (GHashTable *hash, AsTag tag, gboolean is_start)
 {
 	GList *l;
 	GString *str;
@@ -1798,9 +1807,9 @@ as_node_denorm_add_to_langs (GHashTable *hash,
 		xml_lang = l->data;
 		str = g_hash_table_lookup (hash, xml_lang);
 		if (is_start)
-			g_string_append_printf (str, "<%s>", data);
+			g_string_append_printf (str, "<%s>", as_tag_to_string (tag));
 		else
-			g_string_append_printf (str, "</%s>", data);
+			g_string_append_printf (str, "</%s>", as_tag_to_string (tag));
 	}
 }
 
@@ -1856,16 +1865,15 @@ as_node_get_localized_unwrap_type_li (const AsNode *node,
 
 		/* append to existing string, adding the locale if it's not
 		 * already present */
-		if (g_strcmp0 (data->name, "p") == 0) {
+		if (data->tag == AS_TAG_P) {
 			str = as_node_denorm_get_str_for_lang (hash, data, TRUE);
 			as_node_cdata_to_escaped (data);
 			g_string_append_printf (str, "<p>%s</p>",
 						data->cdata);
 
 		/* loop on the children */
-		} else if (g_strcmp0 (data->name, "ul") == 0 ||
-			   g_strcmp0 (data->name, "ol") == 0) {
-			as_node_denorm_add_to_langs (hash, data->name, TRUE);
+		} else if (data->tag == AS_TAG_UL || data->tag == AS_TAG_OL) {
+			as_node_denorm_add_to_langs (hash, data->tag, TRUE);
 			for (tmp_c = tmp->children; tmp_c != NULL; tmp_c = tmp_c->next) {
 				data_c = tmp_c->data;
 
@@ -1879,9 +1887,9 @@ as_node_get_localized_unwrap_type_li (const AsNode *node,
 									       data_c,
 									       TRUE);
 					g_string_append_printf (str, "<%s>",
-								data->name);
+								as_tag_data_get_name (data));
 				}
-				if (g_strcmp0 (data_c->name, "li") == 0) {
+				if (data_c->tag == AS_TAG_LI) {
 					as_node_cdata_to_escaped (data_c);
 					g_string_append_printf (str,
 								"<li>%s</li>",
@@ -1892,18 +1900,19 @@ as_node_get_localized_unwrap_type_li (const AsNode *node,
 						     AS_NODE_ERROR,
 						     AS_NODE_ERROR_INVALID_MARKUP,
 						     "Tag %s in %s invalid",
-						     data_c->name, data->name);
+						     data_c->name,
+						     as_tag_data_get_name (data));
 					return FALSE;
 				}
 			}
-			as_node_denorm_add_to_langs (hash, data->name, FALSE);
+			as_node_denorm_add_to_langs (hash, data->tag, FALSE);
 		} else {
 			/* only <p>, <ul> and <ol> is valid here */
 			g_set_error (error,
 				     AS_NODE_ERROR,
 				     AS_NODE_ERROR_INVALID_MARKUP,
 				     "Unknown tag '%s'",
-				     data->name);
+				     as_tag_data_get_name (data));
 			return FALSE;
 		}
 	}
@@ -1944,20 +1953,19 @@ as_node_get_localized_unwrap_type_ul (const AsNode *node,
 
 		/* append to existing string, adding the locale if it's not
 		 * already present */
-		if (g_strcmp0 (data->name, "p") == 0) {
+		if (data->tag == AS_TAG_P) {
 			str = as_node_denorm_get_str_for_lang (hash, data, TRUE);
 			as_node_cdata_to_escaped (data);
 			g_string_append_printf (str, "<p>%s</p>",
 						data->cdata);
 
 		/* loop on the children */
-		} else if (g_strcmp0 (data->name, "ul") == 0 ||
-			   g_strcmp0 (data->name, "ol") == 0) {
+		} else if (data->tag == AS_TAG_UL || data->tag == AS_TAG_OL) {
 			str = as_node_denorm_get_str_for_lang (hash, data, TRUE);
-			g_string_append_printf (str, "<%s>", data->name);
+			g_string_append_printf (str, "<%s>", as_tag_data_get_name (data));
 			for (tmp_c = tmp->children; tmp_c != NULL; tmp_c = tmp_c->next) {
 				data_c = tmp_c->data;
-				if (g_strcmp0 (data_c->name, "li") == 0) {
+				if (data_c->tag == AS_TAG_LI) {
 					as_node_cdata_to_escaped (data_c);
 					g_string_append_printf (str,
 								"<li>%s</li>",
@@ -1968,24 +1976,52 @@ as_node_get_localized_unwrap_type_ul (const AsNode *node,
 						     AS_NODE_ERROR,
 						     AS_NODE_ERROR_INVALID_MARKUP,
 						     "Tag %s in %s invalid",
-						     data_c->name, data->name);
+						     data_c->name,
+						     as_tag_data_get_name (data));
 					return FALSE;
 				}
 			}
-			g_string_append_printf (str, "</%s>", data->name);
+			g_string_append_printf (str, "</%s>", as_tag_data_get_name (data));
 		} else {
 			/* only <p>, <ul> and <ol> is valid here */
 			g_set_error (error,
 				     AS_NODE_ERROR,
 				     AS_NODE_ERROR_INVALID_MARKUP,
 				     "Unknown tag '%s'",
-				     data->name);
+				     as_tag_data_get_name (data));
 			return FALSE;
 		}
 	}
 	return TRUE;
 }
 
+/**
+ * as_node_fix_locale_full: (skip)
+ * @node: A #AsNode
+ * @locale: The locale
+ *
+ * Fixes and filters incorrect locale strings using the root node to intern the
+ * locale.
+ *
+ * Returns: (transfer full): a newly allocated string
+ *
+ * Since: 0.7.9
+ **/
+AsRefString *
+as_node_fix_locale_full (const GNode *node, const gchar *locale)
+{
+	GNode *root = g_node_get_root ((GNode *) node);
+	AsNodeRoot *root_data = ((AsNodeData *)root->data)->root;
+
+	if (locale == NULL || g_strcmp0 (locale, "C") == 0)
+		return as_ref_string_new_static ("C");
+	if (g_strcmp0 (locale, "xx") == 0)
+		return NULL;
+	if (g_strcmp0 (locale, "x-test") == 0)
+		return NULL;
+	return as_ref_string_ref (as_node_intern (root_data->intern_lang, locale));
+}
+
 /**
  * as_node_fix_locale: (skip)
  * @locale: The locale
@@ -1999,17 +2035,13 @@ as_node_get_localized_unwrap_type_ul (const AsNode *node,
 AsRefString *
 as_node_fix_locale (const gchar *locale)
 {
-	AsRefString *tmp;
-
-	if (locale == NULL)
+	if (locale == NULL || g_strcmp0 (locale, "C") == 0)
 		return as_ref_string_new_static ("C");
 	if (g_strcmp0 (locale, "xx") == 0)
 		return NULL;
 	if (g_strcmp0 (locale, "x-test") == 0)
 		return NULL;
-	tmp = as_ref_string_new (locale);
-	g_strdelimit (tmp, "-", '_'); // FIXME: might be evil
-	return tmp;
+	return as_ref_string_new (locale);
 }
 
 /**
@@ -2045,32 +2077,35 @@ GHashTable *
 as_node_get_localized_unwrap (const AsNode *node, GError **error)
 {
 	AsNodeData *data;
-	GHashTable *results;
+	AsRefString *xml_lang;
 	GList *l;
 	AsNode *tmp;
 	GString *str;
-	const gchar *xml_lang;
 	gboolean is_li_translated = TRUE;
 	g_autoptr(GHashTable) hash = NULL;
+	g_autoptr(GHashTable) results = NULL;
 	g_autoptr(GList) keys = NULL;
 
 	g_return_val_if_fail (node != NULL, NULL);
 
+	/* use AsRefString to be able to ref when subsuming */
+	results = g_hash_table_new_full (g_str_hash, g_str_equal,
+					 (GDestroyNotify) as_ref_string_unref,
+					 (GDestroyNotify) as_ref_string_unref);
+
 	/* work out what kind of normalization this is */
-	xml_lang = as_node_get_attribute (node, "xml:lang");
+	xml_lang = as_node_get_attribute_as_refstr (node, "xml:lang");
 	if (xml_lang != NULL && node->children != NULL) {
 		str = as_node_to_xml (node->children, AS_NODE_TO_XML_FLAG_NONE);
-		results = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 		g_hash_table_insert (results,
-				     g_strdup (xml_lang),
-				     g_strdup (str->str));
+				     as_ref_string_ref (xml_lang),
+				     as_ref_string_new (str->str));
 		g_string_free (str, TRUE);
-		return results;
+		return g_steal_pointer (&results);
 	}
 	for (tmp = node->children; tmp != NULL; tmp = tmp->next) {
 		data = tmp->data;
-		if (g_strcmp0 (data->name, "ul") == 0 ||
-		    g_strcmp0 (data->name, "ol") == 0) {
+		if (data->tag == AS_TAG_UL || data->tag == AS_TAG_OL) {
 			if (as_node_attr_lookup (data, "xml:lang") != NULL) {
 				is_li_translated = FALSE;
 				break;
@@ -2090,22 +2125,19 @@ as_node_get_localized_unwrap (const AsNode *node, GError **error)
 	}
 
 	/* copy into a hash table of the correct size */
-	results = g_hash_table_new_full (g_str_hash, g_str_equal,
-					 (GDestroyNotify) as_ref_string_unref,
-					 (GDestroyNotify) as_ref_string_unref);
 	keys = g_hash_table_get_keys (hash);
 	for (l = keys; l != NULL; l = l->next) {
-		gchar *locale_fixed;
+		g_autoptr(AsRefString) locale_fixed = NULL;
 		xml_lang = l->data;
-		locale_fixed = as_node_fix_locale (xml_lang);
+		locale_fixed = as_node_fix_locale_full (node, xml_lang);
 		if (locale_fixed == NULL)
 			continue;
 		str = g_hash_table_lookup (hash, xml_lang);
 		g_hash_table_insert (results,
-				     locale_fixed,
+				     as_ref_string_ref (locale_fixed),
 				     as_ref_string_new (str->str));
 	}
-	return results;
+	return g_steal_pointer (&results);
 }
 
 /* helper struct */
