@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com`
+ * Copyright (C) 2014-2017 Richard Hughes <richard@hughsie.com`
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -90,6 +90,10 @@ G_BEGIN_DECLS
  * @AS_TAG_REVIEWER_ID:			`reviewer_id`
  * @AS_TAG_SUGGESTS:			`suggests`
  * @AS_TAG_REQUIRES:			`requires`
+ * @AS_TAG_CUSTOM:			`custom`
+ * @AS_TAG_LAUNCHABLE:			`launchable`
+ * @AS_TAG_AGREEMENT:			`agreement`
+ * @AS_TAG_AGREEMENT_SECTION:		`agreement_section`
  *
  * The tag type.
  **/
@@ -152,6 +156,19 @@ typedef enum {
 	AS_TAG_REVIEWER_ID,		/* Since: 0.6.1 */
 	AS_TAG_SUGGESTS,		/* Since: 0.6.1 */
 	AS_TAG_REQUIRES,		/* Since: 0.6.7 */
+	AS_TAG_CUSTOM,			/* Since: 0.6.8 */
+	AS_TAG_LAUNCHABLE,		/* Since: 0.6.13 */
+	AS_TAG_AGREEMENT,		/* Since: 0.7.8 */
+	AS_TAG_AGREEMENT_SECTION,	/* Since: 0.7.8 */
+	AS_TAG_P,			/* Since: 0.7.9 */
+	AS_TAG_LI,			/* Since: 0.7.9 */
+	AS_TAG_UL,			/* Since: 0.7.9 */
+	AS_TAG_OL,			/* Since: 0.7.9 */
+	AS_TAG_BINARY,			/* Since: 0.7.9 */
+	AS_TAG_FONT,			/* Since: 0.7.9 */
+	AS_TAG_DBUS,			/* Since: 0.7.9 */
+	AS_TAG_MODALIAS,		/* Since: 0.7.9 */
+	AS_TAG_LIBRARY,			/* Since: 0.7.9 */
 	/*< private >*/
 	AS_TAG_LAST
 } AsTag;
