@@ -1353,13 +1353,46 @@ as_utils_search_tokenize (const gchar *search)
 	return values;
 }
 
+static gint
+as_utils_vercmp_char (gchar chr1, gchar chr2)
+{
+	if (chr1 == chr2)
+		return 0;
+	if (chr1 == '~')
+		return -1;
+	if (chr2 == '~')
+		return 1;
+	return chr1 < chr2 ? -1 : 1;
+}
+
+static gint
+as_utils_vercmp_chunk (const gchar *str1, const gchar *str2)
+{
+	guint i;
+
+	/* trivial */
+	if (g_strcmp0 (str1, str2) == 0)
+		return 0;
+	if (str1 == NULL)
+		return 1;
+	if (str2 == NULL)
+		return -1;
+
+	/* check each char of the chunk */
+	for (i = 0; str1[i] != '\0' && str2[i] != '\0'; i++) {
+		gint rc = as_utils_vercmp_char (str1[i], str2[i]);
+		if (rc != 0)
+			return rc;
+	}
+	return as_utils_vercmp_char (str1[i], str2[i]);
+}
+
 /**
  * as_utils_vercmp:
  * @version_a: the release version, e.g. 1.2.3
  * @version_b: the release version, e.g. 1.2.3.1
  *
- * Compares version numbers for sorting. This function cannot deal with version
- * strings that do not contain numbers, for instance "rev2706" or "1.2_alpha".
+ * Compares version numbers for sorting.
  *
  * Returns: -1 if a < b, +1 if a > b, 0 if they are equal, and %G_MAXINT on error
  *
@@ -1368,10 +1401,6 @@ as_utils_search_tokenize (const gchar *search)
 gint
 as_utils_vercmp (const gchar *version_a, const gchar *version_b)
 {
-	gchar *endptr;
-	gint64 ver_a;
-	gint64 ver_b;
-	guint i;
 	guint longest_split;
 	g_autofree gchar *str_a = NULL;
 	g_autofree gchar *str_b = NULL;
@@ -1392,9 +1421,11 @@ as_utils_vercmp (const gchar *version_a, const gchar *version_b)
 	split_a = g_strsplit (str_a, ".", -1);
 	split_b = g_strsplit (str_b, ".", -1);
 	longest_split = MAX (g_strv_length (split_a), g_strv_length (split_b));
-	for (i = 0; i < longest_split; i++) {
-		gboolean isnum_a = TRUE;
-		gboolean isnum_b = TRUE;
+	for (guint i = 0; i < longest_split; i++) {
+		gchar *endptr_a = NULL;
+		gchar *endptr_b = NULL;
+		gint64 ver_a;
+		gint64 ver_b;
 
 		/* we lost or gained a dot */
 		if (split_a[i] == NULL)
@@ -1403,32 +1434,20 @@ as_utils_vercmp (const gchar *version_a, const gchar *version_b)
 			return 1;
 
 		/* compare integers */
-		ver_a = g_ascii_strtoll (split_a[i], &endptr, 10);
-		if (endptr != NULL && endptr[0] != '\0')
-			isnum_a = FALSE;
-		if (ver_a < 0)
-			isnum_a = FALSE;
-		ver_b = g_ascii_strtoll (split_b[i], &endptr, 10);
-		if (endptr != NULL && endptr[0] != '\0')
-			isnum_b = FALSE;
-		if (ver_b < 0)
-			isnum_b = FALSE;
-
-		/* can't compare integer with string */
-		if (isnum_a != isnum_b)
-			return G_MAXINT;
+		ver_a = g_ascii_strtoll (split_a[i], &endptr_a, 10);
+		ver_b = g_ascii_strtoll (split_b[i], &endptr_b, 10);
+		if (ver_a < ver_b)
+			return -1;
+		if (ver_a > ver_b)
+			return 1;
 
 		/* compare strings */
-		if (!isnum_a) {
-			gint rc = g_strcmp0 (split_a[i], split_b[i]);
-			if (rc != 0)
-				return rc;
-
-		/* compare integers */
-		} else {
-			if (ver_a < ver_b)
+		if ((endptr_a != NULL && endptr_a[0] != '\0') ||
+		    (endptr_b != NULL && endptr_b[0] != '\0')) {
+			gint rc = as_utils_vercmp_chunk (endptr_a, endptr_b);
+			if (rc < 0)
 				return -1;
-			if (ver_a > ver_b)
+			if (rc > 0)
 				return 1;
 		}
 	}
@@ -1877,20 +1896,23 @@ as_utils_unique_id_is_wildcard_part (const gchar *str, guint len)
 }
 
 /**
- * as_utils_unique_id_equal:
+ * as_utils_unique_id_match:
  * @unique_id1: a unique ID
  * @unique_id2: another unique ID
+ * @match_flags: a #AsUniqueIdMatchFlags bitfield, e.g. %AS_UNIQUE_ID_MATCH_FLAG_ID
  *
- * Checks two unique IDs for equality allowing globs to match.
+ * Checks two unique IDs for equality allowing globs to match, whilst also
+ * allowing clients to whitelist sections that have to match.
  *
  * Returns: %TRUE if the ID's should be considered equal.
  *
- * Since: 0.6.1
+ * Since: 0.7.8
  */
 gboolean
-as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
+as_utils_unique_id_match (const gchar *unique_id1,
+			  const gchar *unique_id2,
+			  AsUniqueIdMatchFlags match_flags)
 {
-	guint i;
 	guint last1 = 0;
 	guint last2 = 0;
 	guint len1;
@@ -1906,7 +1928,7 @@ as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
 		return g_strcmp0 (unique_id1, unique_id2) == 0;
 
 	/* look at each part */
-	for (i = 0; i < AS_UTILS_UNIQUE_ID_PARTS; i++) {
+	for (guint i = 0; i < AS_UTILS_UNIQUE_ID_PARTS; i++) {
 		const gchar *tmp1 = unique_id1 + last1;
 		const gchar *tmp2 = unique_id2 + last2;
 
@@ -1915,7 +1937,8 @@ as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
 		len2 = as_utils_unique_id_find_part (tmp2);
 
 		/* either string was a wildcard */
-		if (!as_utils_unique_id_is_wildcard_part (tmp1, len1) &&
+		if (match_flags & (1 << i) &&
+		    !as_utils_unique_id_is_wildcard_part (tmp1, len1) &&
 		    !as_utils_unique_id_is_wildcard_part (tmp2, len2)) {
 			/* are substrings the same */
 			if (len1 != len2)
@@ -1931,6 +1954,30 @@ as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
 	return TRUE;
 }
 
+/**
+ * as_utils_unique_id_equal:
+ * @unique_id1: a unique ID
+ * @unique_id2: another unique ID
+ *
+ * Checks two unique IDs for equality allowing globs to match.
+ *
+ * Returns: %TRUE if the ID's should be considered equal.
+ *
+ * Since: 0.6.1
+ */
+gboolean
+as_utils_unique_id_equal (const gchar *unique_id1, const gchar *unique_id2)
+{
+	return as_utils_unique_id_match (unique_id1,
+					 unique_id2,
+					 AS_UNIQUE_ID_MATCH_FLAG_SCOPE |
+					 AS_UNIQUE_ID_MATCH_FLAG_BUNDLE_KIND |
+					 AS_UNIQUE_ID_MATCH_FLAG_ORIGIN |
+					 AS_UNIQUE_ID_MATCH_FLAG_KIND |
+					 AS_UNIQUE_ID_MATCH_FLAG_ID |
+					 AS_UNIQUE_ID_MATCH_FLAG_BRANCH);
+}
+
 /**
  * as_utils_unique_id_hash:
  * @unique_id: a unique ID
